/*
 * Copyright (C) 2000  Ross Combs (rocombs@cs.nmsu.edu)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#ifndef INCLUDED_GETTIMEOFDAY_TYPES
#define INCLUDED_GETTIMEOFDAY_TYPES

#ifdef HAVE_SYS_TIME_H
# include <sys/time.h>
#endif

#ifndef HAVE_GETTIMEOFDAY

namespace pvpgn
{

	/* FIXME: these might already exist even if gettimeofday() doesn't */
	struct timeval
	{
		long tv_sec;
		long tv_usec;
	};


	struct timezone
	{
		int tz_minuteswest;
		int tz_dsttime;
	};

}

#endif

#endif


#ifndef INCLUDED_GETTIMEOFDAY_PROTOS
#define INCLUDED_GETTIMEOFDAY_PROTOS

#ifndef HAVE_GETTIMEOFDAY
namespace pvpgn
{

	extern int gettimeofday(struct timeval * tv, struct timezone * tz);

}
#endif

#endif
